@@ -63,7 +63,7 @@ const NETWORK_TEST_ADDRESS_BOOK: &str =
 /// When Submitting transactions you need to either submit gas or a fee to the validator
 /// This structure is used to determine what your preferences are by default
 /// Higher fees may be given preference by the validator to include the transaction in their block
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct GasOptions {
     /// If specified the TX will use the fee specified
     pub fees: Option<Coin>,
@@ -107,7 +107,7 @@ impl GasOptions {
         fcd_url: &str,
         gas_denom: &str,
         gas_adjustment: f64,
-    ) -> anyhow::Result<GasOptions> {
+    ) -> Result<GasOptions, TerraRustAPIError> {
         let prices = fcd::FCD::fetch_gas_prices(client, fcd_url).await?;
         if let Some(price) = prices.get(gas_denom) {
             let gas_coin = Coin::create(gas_denom, *price);
@@ -120,7 +120,7 @@ impl GasOptions {
                 gas_adjustment: Some(gas_adjustment),
             })
         } else {
-            Err(GasPriceError(gas_denom.into()).into())
+            Err(GasPriceError(gas_denom.into()))
         }
     }
 }
