@@ -1,5 +1,6 @@
 use crate::client::staking_types::{Validator, ValidatorDelegation, ValidatorUnbondingDelegation};
 use crate::errors::TerraRustAPIError;
+use crate::staking_types::ValidatorDelegationsV1Response;
 use crate::{LCDResult, Terra};
 
 pub struct Staking<'a> {
@@ -46,6 +47,22 @@ impl Staking<'_> {
             )
             .await
     }
+    /// all delegations for a given validator (limit) (new format)
+    pub async fn validator_delegations_limit(
+        &self,
+        key: &str,
+        limit: u64,
+    ) -> Result<ValidatorDelegationsV1Response, TerraRustAPIError> {
+        self.terra
+            .send_cmd::<ValidatorDelegationsV1Response>(
+                &format!(
+                    "/cosmos/staking/v1beta1/validators/{}/delegations?pagination.limit={}",
+                    key, limit
+                ),
+                None,
+            )
+            .await
+    }
 
     /// all unbondings for a given validator
     pub async fn validator_unbonding_delegations(
