@@ -6,11 +6,11 @@ use crate::Terra;
 use serde::Deserialize;
 
 pub struct Wasm<'a> {
-    terra: &'a Terra<'a>,
+    terra: &'a Terra,
 }
 
 impl Wasm<'_> {
-    pub fn create<'a>(terra: &'a Terra) -> Wasm<'a> {
+    pub fn create(terra: &'_ Terra) -> Wasm<'_> {
         Wasm { terra }
     }
     pub async fn codes(&self, code_id: u64) -> anyhow::Result<WasmCodeResult> {
